# Name

Short description of this method.

## Description

Description of the method.

## Motivation for developing this method

Description of the limitation of the referenced methods and how this method solve the problem.

## Key Differences

Description of the difference between this method and the referenced methods.

## Benchmark Performance

Link to the benchmark performance of the method.
